==> haskell-hasql-pool-0.5.2.2-333-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-pool
version:              0.5.2.2
visibility:           public
id:                   hasql-pool-0.5.2.2-KM94D2ivmKy789JOppjZRf
key:                  hasql-pool-0.5.2.2-KM94D2ivmKy789JOppjZRf
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-pool 
synopsis:             A pool of connections for Hasql
category:             Hasql, Database, PostgreSQL
abi:                  e6417006aeff23e215413ef56e14e398
exposed:              True
exposed-modules:      Hasql.Pool
hidden-modules:       Hasql.Pool.Prelude Hasql.Pool.ResourcePool
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasql-pool-0.5.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasql-pool-0.5.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasql-pool-0.5.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-pool
hs-libraries:         HShasql-pool-0.5.2.2-KM94D2ivmKy789JOppjZRf
depends:
    base-prelude-1.6.1.1-GKFFatabSp72iGYTIzDMDA
    hasql-1.5.0.5-I3LpRXfzXVTC67F3ohwQHt
    resource-pool-0.2.3.2-1IAL1hRKBL1GrOGhYvkTiF time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html:         /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-pool-0.5.2.2-334-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-pool
version:              0.5.2.2
visibility:           public
id:                   hasql-pool-0.5.2.2-G9tOY0onb7WB3vKkbZZK0T
key:                  hasql-pool-0.5.2.2-G9tOY0onb7WB3vKkbZZK0T
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-pool 
synopsis:             A pool of connections for Hasql
category:             Hasql, Database, PostgreSQL
abi:                  66e9534903b76b293d664ecbb6804d67
exposed:              True
exposed-modules:      Hasql.Pool
hidden-modules:       Hasql.Pool.Prelude Hasql.Pool.ResourcePool
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hasql-pool-0.5.2.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hasql-pool-0.5.2.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hasql-pool-0.5.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-pool
hs-libraries:         HShasql-pool-0.5.2.2-G9tOY0onb7WB3vKkbZZK0T
depends:
    base-prelude-1.6.1.1-GKFFatabSp72iGYTIzDMDA
    hasql-1.5.0.5-9hzI1nJuJnOBUrbSel0Cty
    resource-pool-0.2.3.2-9pY30h3Q5a1HDMTKsGpvMS time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html:         /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
